@@ -147,7 +147,7 @@ class CodeGen(Visitor[JSVisitorContext]):
         builder = BaseBuilder()\
             .write(f'let {node.name} = class')\
             .write(SurroundBuilder(surround='{}')
-                   .write_if(self.python_compatible, lambda: '''constructor(...args) {if ('__init__' in this) this.__init__(...args); return new Proxy(this, { apply: (target, self, args) => target.__call__(self, ...args)})}''')
+                   .write_if(self.python_compatible, lambda: '''constructor(...args) {if ('__init__' in this) this.__init__(...args); return new Proxy(this, { apply: (target, self, args) => target.__call__(...args), get: (target, key) => target.__getitem__(key) })}''')
                    .write(self.visit(filter(lambda node: isinstance(node, ast.FunctionDef), body), context))
                    .write(self.visit(filter(lambda node: not isinstance(node, ast.FunctionDef), body), context))
                    )\
@@ -260,11 +260,12 @@ class CodeGen(Visitor[JSVisitorContext]):
         defines = [target.id for target in node.targets if isinstance(target, ast.Name) and not ctx.is_existed(target.id)]
         ctx.variables.extend(defines)
 
-        if len(node.targets) == len(defines):
-            builder.write(f'let {", ".join(defines)} = {self.visit(node.value, ctx)}')
-            return builder.build()
-        elif defines:
-            builder.write(f'let {", ".join(defines)}')
+        if ctx.scope != JSScope.CLASS_FIELD:
+            if len(node.targets) == len(defines):
+                builder.write(f'let {", ".join(defines)} = {self.visit(node.value, ctx)}')
+                return builder.build()
+            elif defines:
+                builder.write(f'let {", ".join(defines)}')
         builder.write(f'{self.visit(node.targets, ctx)} = {self.visit(node.value, ctx)}')
         return builder.build()
         # return BaseBuilder().write_if(node.targets in ctx.variables and ctx.scope != JSScope.CLASS_FIELD and not any(map(lambda target: isinstance(target, ast.Attribute), node.targets)), 'let').write(f'{self.visit(node.targets, ctx)} = {self.visit(node.value, ctx)}').build()
